/*
 * This file is part of the segmentation and registration toolkit (SphereSegRegTk).
 *
 * SphereSegRegTk is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SphereSegRegTk is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SphereSegRegTk.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * storage to handle points with radius with a standard for all classes
 */
#ifndef CPOINTRADIUS_HPP
#define CPOINTRADIUS_HPP


/// Handler for nD position and sphere radius
template <int N, typename T>
class CPointRadius
{
public:
	CVector<N,T> pos;	///< position
	T radius;		///< sphere radius

	inline CPointRadius<N,T> &operator=(CPointRadius<N,T> &p)
	{
		pos = p.pos;
		radius = p.radius;
		return *this;
	}

	inline CPointRadius<N,T>()
	{
		pos.setZero();
		radius = 0;
	}

	inline CPointRadius<N,T>(CVector<N,T> &p_pos, T p_radius)
	{
		pos = p_pos;
		radius = p_radius;
	}

	struct compareSet
	{
		inline bool operator()(const CPointRadius<N,T> &p1, const CPointRadius<N,T> &p2)
		{
			if (p1.pos.data[0] != p2.pos.data[0])
				return p1.pos.data[0] < p2.pos.data[0];
			if (p1.pos.data[1] != p2.pos.data[1])
				return p1.pos.data[1] < p2.pos.data[1];
			if (p1.pos.data[2] != p2.pos.data[2])
				return p1.pos.data[2] < p2.pos.data[2];
			return false;
		}
	};
};

#endif
